@@ -13,6 +13,7 @@ def get_nodes_from_env_info(env_info: dict) -> Nodes:
             int_ip=raw_node["intIP"],
             node_type=raw_node["nodeType"],
             node_group=raw_node["nodeGroup"],
+            url=raw_node["url"],
             display_name=raw_node["displayName"] if "displayName" in raw_node else None)
         nodes.append(node)
     return nodes
@@ -39,28 +40,43 @@ class EnvInfo:
     def exists(self) -> bool:
         return self.status() is not EnvStatus.NotExists and self.status() is not EnvStatus.Unknown
 
-    def get_node_ips(self, node_group: str = None, node_type: str = None) -> [str]:
+    def get_nodes(self, node_group: str = None, node_type: str = None) -> Nodes:
         env_nodes = self._nodes
 
-        node_ips_with_node_group = []
+        nodes_with_node_group = []
         if node_group is not None:
-            node_ips_with_node_group = [env_node.int_ip for env_node in env_nodes if
-                                        env_node.node_group == node_group]
+            nodes_with_node_group = [env_node for env_node in env_nodes if
+                                     env_node.node_group == node_group]
             if node_type is None:
-                return node_ips_with_node_group
+                return nodes_with_node_group
 
-        node_ips_with_node_type = []
+        nodes_with_node_type = []
         if node_type is not None:
-            node_ips_with_node_type = [
-                env_node.int_ip for env_node in env_nodes if env_node.node_type == node_type]
+            nodes_with_node_type = [
+                env_node for env_node in env_nodes if env_node.node_type == node_type]
             if node_group is None:
-                return node_ips_with_node_type
+                return nodes_with_node_type
 
-        return list(set(node_ips_with_node_type)
-                    .intersection(node_ips_with_node_group))
+        return list(set(nodes_with_node_type)
+                    .intersection(nodes_with_node_group))
 
-    def get_node_ip_from_name(self, display_name: str):
-        node_ips_with_display_name = [
-            env_node.int_ip for env_node in self._nodes if env_node.display_name == display_name]
+    def get_node_from_name(self, display_name: str) -> Node:
+        nodes_with_display_name = [
+            env_node for env_node in self._nodes if env_node.display_name == display_name]
+        return nodes_with_display_name[0] if len(nodes_with_display_name) == 1 else None
 
-        return node_ips_with_display_name[0] if len(node_ips_with_display_name) == 1 else None
+    def get_node_ips(self, node_group: str = None, node_type: str = None) -> [str]:
+        nodes = self.get_nodes(node_group, node_type)
+        return [node.int_ip for node in nodes]
+
+    def get_node_ip_from_name(self, display_name: str) -> str:
+        node = self.get_node_from_name(display_name)
+        return node.int_ip if node is not None else None
+
+    def get_node_hostname_from_name(self, display_name: str) -> str:
+        node = self.get_node_from_name(display_name)
+        if node is None:
+            return None
+        url = node.url
+        hostname = url.split('://')[1]
+        return hostname
